component_information: switch from gzip to xz

Improves compression, e.g. current params file: 62KB to 51KB

There's also a PRESET_EXTREME option, which reduces by another 2KB.
We can revisit that once needed, as it increases mem usage as well.
This commit is contained in:
Beat Küng
2021-02-09 09:44:50 +01:00
parent cedfae9e46
commit 5a1c60b5a1
8 changed files with 22 additions and 22 deletions
+1 -1
View File
@@ -83,7 +83,7 @@ def main():
# only prune text files
if ".zip" in file or ".bin" in file or ".swp" in file \
or ".gz" in file or ".bz2" in file \
or ".gz" in file or ".xz" in file or ".bz2" in file \
or ".data" in file or ".DS_Store" in file:
continue